==> hadoop-2.10.1-src.tar.gz: hadoop-2.10.1-src/hadoop-yarn-project/hadoop-yarn/hadoop-yarn-server/hadoop-yarn-server-resourcemanager/src/main/java/org/apache/hadoop/yarn/server/resourcemanager/scheduler/SchedulerAppUtils.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.yarn.server.resourcemanager.scheduler;

import org.apache.commons.logging.Log;

public class SchedulerAppUtils {

  public static boolean isPlaceBlacklisted(
      SchedulerApplicationAttempt application, SchedulerNode node, Log log) {
    if (application.isPlaceBlacklisted(node.getNodeName())) {
      if (log.isDebugEnabled()) {
        log.debug("Skipping 'host' " + node.getNodeName() +
            " for " + application.getApplicationId() +
            " since it has been blacklisted");
      }
      return true;
    }

    if (application.isPlaceBlacklisted(node.getRackName())) {
      if (log.isDebugEnabled()) {
        log.debug("Skipping 'rack' " + node.getRackName() +
            " for " + application.getApplicationId() +
            " since it has been blacklisted");
      }
      return true;
    }

    return false;
  }

}

==> hadoop-3.2.3-src.tar.gz: hadoop-3.2.3-src/hadoop-yarn-project/hadoop-yarn/hadoop-yarn-server/hadoop-yarn-server-resourcemanager/src/main/java/org/apache/hadoop/yarn/server/resourcemanager/scheduler/SchedulerAppUtils.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.yarn.server.resourcemanager.scheduler;

import org.slf4j.Logger;

public class SchedulerAppUtils {

  public static boolean isPlaceBlacklisted(
      SchedulerApplicationAttempt application, SchedulerNode node,
      Logger log) {
    if (application.isPlaceBlacklisted(node.getNodeName())) {
      if (log.isDebugEnabled()) {
        log.debug("Skipping 'host' " + node.getNodeName() +
            " for " + application.getApplicationId() +
            " since it has been blacklisted");
      }
      return true;
    }

    if (application.isPlaceBlacklisted(node.getRackName())) {
      if (log.isDebugEnabled()) {
        log.debug("Skipping 'rack' " + node.getRackName() +
            " for " + application.getApplicationId() +
            " since it has been blacklisted");
      }
      return true;
    }

    return false;
  }

}
